package edu.ntnu.stud.chaosgame.model.generators;

import edu.ntnu.stud.chaosgame.controller.game.ChaosGameDescription;
import edu.ntnu.stud.chaosgame.controller.game.ChaosGameFileHandler;
import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Objects;

/**
 * Class that generates a set number of ChaosGameDescription instances using a set of
 * files read by a ChaosGameFileHandler.
 */
public class ChaosGameDescriptionFactory {

  /**
   * The list of all the descriptions generated from the data in the directory specified
   * in constructor.
   */
  private final ArrayList<ChaosGameDescription> descriptions;

  /**
   * Generate ChaosGameDescription-instances based on data in txt-files found in the directory.
   * The naming of the txt-files must follow the pattern "desc_X.txt" where X is an integer
   * incremented by 1 for each file in the directory.
   *
   * @throws IOException if the method fails to read successfully from one of the data files.
   */
  public ChaosGameDescriptionFactory() throws IOException {
    /**
     * The directory where the descriptions are located.
     */
    String directory1 = "src/main/resources/descriptions/factory/";
    this.descriptions = new ArrayList<>();
    ChaosGameFileHandler handler = new ChaosGameFileHandler();
    File directory = new File(directory1);
    int fileCount = Objects.requireNonNull(directory.list()).length;

    for (int i = 0; i < fileCount; i++) {
      this.descriptions.add(handler.readFromFile(directory1 + "desc_" + (i + 1) + ".txt"));
    }
  }

  /**
   * Get the list of descriptions.
   *
   * @return the list.
   */
  public ArrayList<ChaosGameDescription> getDescriptions() { return this.descriptions; }

}
